"""
MonarchV3_phenotype_similarity_search

Find diseases that best match a set of phenotypes (HPO terms) using semantic similarity from the ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def MonarchV3_phenotype_similarity_search(
    phenotypes: list[str],
    group: Optional[str] = None,
    limit: Optional[int] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> list[Any]:
    """
    Find diseases that best match a set of phenotypes (HPO terms) using semantic similarity from the ...

    Parameters
    ----------
    phenotypes : list[str]
        List of HPO term CURIEs representing observed phenotypes. Examples: ['HP:0001...
    group : str
        Entity group to search against. Default: 'Human Diseases'. Options: 'Human Di...
    limit : int
        Maximum number of matching diseases to return (default: 10, max: 50).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    list[Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v
        for k, v in {"phenotypes": phenotypes, "group": group, "limit": limit}.items()
        if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "MonarchV3_phenotype_similarity_search",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["MonarchV3_phenotype_similarity_search"]
